# -*- coding: utf-8 -*-

"""
Top-level package for Countdoom.

SPDX-License-Identifier: MIT
"""

__author__ = """René-Marc Simard"""
__email__ = 'renemarc@gmail.com'
__license__ = 'MIT'
__url__ = 'https://github.com/renemarc/countdoom'
__version__ = '0.2.1'

from .client import CountdoomClient, CountdoomClientError  # noqa: F401
